pub trait Transform {
// Required methods
fn transform_error(&self, msg: String) -> String;
fn transform_warning(&self, msg: String) -> String;
}Required Methods
Sourcefn transform_error(&self, msg: String) -> String
fn transform_error(&self, msg: String) -> String
Transform the error log message that contains warn (case insensitive).
Sourcefn transform_warning(&self, msg: String) -> String
fn transform_warning(&self, msg: String) -> String
Transform the warning log message that does not contain warn (case insensitive).